@@ -36,3 +36,15 @@ hash_xinitialize (size_t candidate, const Hash_tuning *tuning,
     xalloc_die ();
   return res;
 }
+
+/* Same as hash_insert, but invokes xalloc_die on memory
+   exhaustion.  */
+
+void *
+hash_xinsert (Hash_table *table, void const *entry)
+{
+  void *res = hash_insert (table, entry);
+  if (!res)
+    xalloc_die ();
+  return res;
+}
